pub fn run_blocking(opts: TraceOptions) -> Result<()>Expand description
Run the trace daemon to completion (until the source ends), blocking on a fresh Tokio runtime so the caller stays synchronous.
pub fn run_blocking(opts: TraceOptions) -> Result<()>Run the trace daemon to completion (until the source ends), blocking on a fresh Tokio runtime so the caller stays synchronous.